@@ -1,4 +1,4 @@
-from gitty import GittyCommand, GitCommandStep, CommentStep
+from gitty import GittyCommand, GitCommandStep, CommentStep, GitCheckoutExistingCommand
 
 
 class GittyParent(GittyCommand):
@@ -7,7 +7,7 @@ class GittyParent(GittyCommand):
     _bindings = ['p', 'parent']
     _steps = [
         CommentStep('go to parent branch (%s)', ['parent_version_branch']),
-        GitCommandStep('git checkout %s', ['parent_version_branch'])
+        GitCheckoutExistingCommand('parent_version_branch')
     ]
 
     def is_available(self, context):
@@ -17,7 +17,7 @@ class GittyParent(GittyCommand):
 
     def do_it(self, context):
         for step in self._steps:
-            step.execute(context)
+            step.execute(context, False)
 
     def get_description(self, context):
         description = []
